Learn R Programming

fisheye (version 0.2.0)

fisheye-package: Package description

Description

Base maps are transformed to focus on a specific location using an azimuthal logarithmic distance transformation.

Arguments

References

Hägerstrand, T. (1957). Migration and Area: A Survey of a Sample of Swedish Migration Fields and Hypothetical Considerations of their Genesis. Lund Studies in Geography, Series B, Human Geography, Department of Geography, University of Lund, Lund.